@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,8 @@
 # You should have received a copy of the GNU General Public License
 # along with the R software environment if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-# or see http://www.r-project.org/Licenses/GPL-2    
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 poly.image.regrid <- function(x) {
     ##################################
     temp.addcol <- function(X) {
@@ -40,7 +41,7 @@ poly.image.regrid <- function(x) {
 poly.image <- function(x, y, z, col = tim.colors(64), 
     breaks, transparent.color = "white", midpoint = FALSE, zlim = range(z, 
         na.rm = TRUE), xlim = range(x), ylim = range(y), add = FALSE, 
-    border = NA, lwd.poly = 1, ...) {
+    border = NA, lwd.poly = 1, asp=NA, ...) {
     # check dimensions
     Dx <- dim(x)
     Dy <- dim(y)
@@ -66,7 +67,7 @@ poly.image <- function(x, y, z, col = tim.colors(64),
         transparent.color = transparent.color, breaks = breaks)$color.index
     # blank if not adding to an exising plot
     if (!add) {
-        plot(xlim, ylim, type = "n", ...)
+        plot(xlim, ylim, type = "n",asp=asp,  ...)
     }
     N <- ncol(x)
     Nm1 <- N - 1
@@ -82,6 +83,7 @@ poly.image <- function(x, y, z, col = tim.colors(64),
             y[i, 2:N], rep(NA, Nm1))
         xp <- c(t(xp))
         yp <- c(t(yp))
+       
         pcol <- c(zcol[i, 1:Nm1])
         
         # draw each poly with different color including the border
@@ -93,6 +95,8 @@ poly.image <- function(x, y, z, col = tim.colors(64),
         
         # fill in border with different color if it is not an NA.
         if (!is.na(border)) {
+# this does not quite work           
+#  borderWithNA<- ifelse( pcol == transparent.color, NA,border)
             polygon(xp, yp, border = border, col = NA, lwd = lwd.poly)
         }
         
