@@ -1,9 +1,9 @@
+#
 # fields  is a package for analysis of spatial data written for
-# the R software environment .
-# Copyright (C) 2018
-# University Corporation for Atmospheric Research (UCAR)
-# Contact: Douglas Nychka, nychka@ucar.edu,
-# National Center for Atmospheric Research, PO Box 3000, Boulder, CO 80307-3000
+# the R software environment.
+# Copyright (C) 2022 Colorado School of Mines
+# 1500 Illinois St., Golden, CO 80401
+# Contact: Douglas Nychka,  douglasnychka@gmail.edu,
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,6 +14,11 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
+# You should have received a copy of the GNU General Public License
+# along with the R software environment if not, write to the Free Software
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+# or see http://www.r-project.org/Licenses/GPL-2
+##END HEADER
 print.spatialProcessSummary <- function(x, digits = 4, ...) {
   cat("CALL:\n")
   dput(x$call)
@@ -21,10 +26,18 @@ print.spatialProcessSummary <- function(x, digits = 4, ...) {
   cat(" SUMMARY OF MODEL FIT:\n")
   print(x$summaryTable, quote = FALSE)
   cat("\n")
+  if( !is.na(x$fixedEffectsTable[1])){
   cat(" ESTIMATED COEFFICIENTS FOR FIXED PART:", fill = TRUE)
   cat("\n")
   print(x$fixedEffectsTable, quote = FALSE)
   cat("\n")
+  }
+  if( !is.na(x$fixedEffectsTableCommon[1])){
+  cat(" ESTIMATED COEFFICIENTS FOR COMMON COVARIATES:", fill = TRUE)
+  cat("\n")
+  print(x$fixedEffectsTableCommon, quote = FALSE)
+  cat("\n")
+  }
   cat(" COVARIANCE MODEL:", x$cov.function, fill = TRUE)
   if (x$cov.function == "stationary.cov") {
     covName<- ifelse(is.null(x$args$Covariance), 
